@@ -983,7 +983,9 @@ class UnionBlock(Block):
       if r: return r
       
     for i in self:
+      if not isinstance(i, SimpleTripleBlock): return None
       if len(i) > 1: return None
+      if not isinstance(i[0], Triple): return None
       
     ss = set()
     ps = set()
@@ -1068,8 +1070,10 @@ class SubQueryBlock(Block):
 
 class Triple(tuple):
   def __init__(self, l):
-    self.optional = False
-    self.var_names = { x.value for x in self if x.name == "VAR" }
+    self.optional     = False
+    self.likelihood_p = None
+    self.likelihood_o = None
+    self.var_names    = { x.value for x in self if x.name == "VAR" }
     p_storid = getattr(self[1], "storid", None)
     self.Prop = p_storid and CURRENT_TRANSLATOR.get().world._get_by_storid(p_storid)
     
@@ -1082,6 +1086,22 @@ class Triple(tuple):
     elif isinstance(self.Prop, DataPropertyClass):   self.table_type = "datas"
     else:                                            self.table_type = "quads"
     
+    #if (getattr(self[1], "storid", None) == rdf_type) and (self[2].name == "IRI"):
+    #  self.likelihood_o = 0.9375
+    #if (getattr(self[1], "storid", None) == rdfs_subclassof) and (self[2].name == "IRI"):
+    #  self.likelihood_o = 0.7
+    #if (getattr(self[1], "storid", None) == rdf_type):
+    #  self.likelihood_p = 0.2
+    #  self.likelihood_o = 0.2
+    #if (getattr(self[1], "storid", None) == rdfs_subclassof):
+    #  self.likelihood_p = 0.1
+    #  self.likelihood_o = 0.15
+    #if (getattr(self[1], "storid", None) == label.storid) and (self[2].name == "STRING"):
+    #  self.likelihood_o = 0.01
+    #elif self.Prop and self.Prop.range == [bool]:
+    #  self.likelihood_o = 0.5
+      
+    
   def _get_ordered_vars(self, vars, ordered_vars):
     if self[1].inversed: triple = self[::-1]
     else:                triple = self
@@ -1146,7 +1166,10 @@ class Filter(object):
     self.constraint = constraint
     self.var_names = set(_get_vars(constraint))
     
-  def _get_ordered_vars(self, vars, ordered_vars): pass
-  
+  def _get_ordered_vars(self, vars, ordered_vars):
+    for var in self.var_names:
+      _var_found(var, vars, ordered_vars)
+    #pass
+    
   
   
